import pylab

def get_chemical_potential(nc):
    chemical_potentials = nlread(nc, ChemicalPotential)
    #assert len(chemical_potentials) == 1
    chemical_potential = -1*chemical_potentials[-1].evaluate().inUnitsOf(eV)[0]
    return chemical_potential

def get_average_potential(nc):
    potentials = nlread(nc, ElectrostaticDifferencePotential)
    assert len(potentials) == 1
    edp = potentials[0]
    projection = edp.axisProjection('average', 'c')
    return projection[1][-1].inUnitsOf(eV)

def get_surface_wf(nc):
    chemical_potential = get_chemical_potential(nc)
    average_potential = get_average_potential(nc)
    return chemical_potential + average_potential

x = [2,3,4,5,6,7,8,9,10,11,12,13,14,15,16]
x1 = []
y1 = []
x2 = []
y2 = []
for i in x:
    # slab calculation
    nc1 = 'Ag100_slab_%i.nc' % i
    y1.append(get_chemical_potential(nc1))
    x1.append(i*2-2) # subtract the ghost layer
    # surface calculation
    nc2 = 'Ag100_surface_%i.nc' % i
    y2.append(get_surface_wf(nc2))
    x2.append(i*2) # subtract ther ghost layer, but include the electrode layers

pylab.plot(x1,y1, 'bo-', label='Slab calculations')
pylab.plot(x2,y2, 'rs--', label="Green's function surface calculations")

pylab.xticks(x1)
pylab.xlabel('Number of metal layers')
pylab.ylabel('Work function (eV)')
pylab.ylim([4.42, 4.60])

pylab.legend()
pylab.show()
